"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ipynb2html_1 = require("ipynb2html");
const notebookCss = "/* Reference styles for ipynb2html */\n\n.nb-notebook {\n  line-height: 1.5;\n}\n\n.nb-cell + .nb-cell {\n  margin-top: 1.4rem;\n}\n\n.nb-raw-cell {\n  font-family: monospace;\n  white-space: pre-wrap;\n}\n\n.nb-code-cell {\n  position: relative;\n}\n\n.nb-source::before,\n.nb-output::before {\n  position: absolute;\n  font-family: monospace;\n  color: #999;\n  left: -7.5em;\n  width: 7em;\n  text-align: right;\n}\n\n.nb-source::before {\n  content: \"In [\" attr(data-execution-count) \"]:\";\n}\n.nb-output::before {\n  content: \"Out[\" attr(data-execution-count) \"]:\";\n}\n\n.nb-source + .nb-output,\n.nb-output + .nb-output {\n  margin-top: 1.4rem;\n}\n\n.nb-source > pre {\n  background-color: #f7f7f7;\n  border: 1px solid #cfcfcf;\n  border-radius: 2px;\n  padding: 0.5em;\n  margin: 0;\n  overflow-x: auto;\n}\n\n.nb-output {\n  min-height: 1em;\n  width: 100%;\n}\n\n.nb-output > pre {\n  padding: 0.5em;\n  margin: 0;\n  overflow-x: auto;\n}\n\n.nb-output > img {\n  max-width: 100%;\n}\n\n.nb-stdout,\n.nb-stderr {\n  white-space: pre-wrap;\n}\n\n.nb-error,\n.nb-stderr {\n  background-color: #fdd;\n  border-radius: 2px;\n}\n\n@media (max-width: 768px) {\n  .nb-source::before,\n  .nb-output::before {\n    display: block;\n    position: relative;\n    left: 0;\n    padding-bottom: 0.5em;\n    text-align: left;\n  }\n}\n";
const pageCss = "html, body {\n  margin: 0;\n  padding: 0;\n  background-color: #dedede;\n  color: #2a2a2a;\n  font-family: sans-serif;\n}\n\ncode,\npre {\n  font-size: 0.85rem;\n}\n\nh1, h2, h3, h4, h5, h6 {\n  margin-top: 1.6em;\n  position: relative;\n}\n\nh1 .anchor,\nh2 .anchor,\nh3 .anchor,\nh4 .anchor,\nh5 .anchor,\nh6 .anchor {\n  display: block;\n  width: 1em;\n  left: -1em;\n  height: 100%;\n  position: absolute;\n}\n\nh1:hover .anchor,\nh2:hover .anchor,\nh3:hover .anchor,\nh4:hover .anchor,\nh5:hover .anchor,\nh6:hover .anchor {\n  background: url(\"data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 50 50'%3E%3Cg fill='none' stroke='%23000' stroke-width='3'%3E%3Cpath d='M26.1 22a5.8 5.8 0 00-8.1 0l-9.6 9.5a5.8 5.8 0 008.2 8.2l5.8-5.9'/%3E%3Cpath d='M23.6 28a5.8 5.8 0 008.2 0l9.5-9.5a5.8 5.8 0 00-8.1-8.2l-5.8 5.9'/%3E%3C/g%3E%3C/svg%3E\") no-repeat 100% center;\n}\n\ntable {\n  border-collapse: collapse;\n  border: 1px solid #cfcfcf;\n}\n\nth {\n  font-weight: 600;\n}\n\ntd,\nth {\n  padding: 0.2em 0.4em;\n  border: 1px solid #cfcfcf;\n}\n\nthead tr,\ntbody tr:nth-child(even) {\n  background-color: #f7f7f7;\n}\n\nthead tr:hover,\ntbody tr:hover {\n  background-color: #cfcfcf;\n}\n\n.nb-notebook {\n  max-width: 45rem;\n  margin: 1rem auto;\n  padding: 3rem 6rem;\n  background-color: white;\n  box-shadow: 4px 4px 8px #cfcfcf, -4px -4px 8px #cfcfcf;\n}\n\n.nb-output table {\n  font-size: 0.9em;\n}\n\n@media (max-width: 900px) {\n  .nb-notebook {\n    margin: 0;\n    padding-left: 5rem;\n    padding-right: 3rem;\n    max-width: none;\n    box-shadow: none;\n  }\n}\n\n@media (max-width: 768px) {\n  .nb-notebook {\n    padding: 1rem 5% 2rem 5%;\n  }\n}\n";
const page = (contents, title) => `\
<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="initial-scale=1">
    <meta name="generator" content="ipynb2html ${ipynb2html_1.version}">
    <title>${title}</title>
    <link rel="stylesheet"
        href="https://cdn.jsdelivr.net/gh/highlightjs/cdn-release@9.15.10/build/styles/default.min.css"
        integrity="sha384-ut3ELVx81ErZQaaMTknSmGb0CEGAKoBFTamRcY1ddG4guN0aoga4C+B6B7Kv1Ll1"
        crossorigin="anonymous">
    <link rel="stylesheet"
        href="https://cdn.jsdelivr.net/npm/katex@0.11.0/dist/katex.min.css"
        integrity="sha384-BdGj8xC2eZkQaxoQ8nSLefg4AV4/AwB3Fj+8SUSo7pnKP6Eoy18liIKTPn9oBYNG"
        crossorigin="anonymous">
    <style>
${(pageCss + notebookCss).slice(0, -1).replace(/\n\n/g, '\n').replace(/^/gm, '      ')}
    </style>
  </head>
  <body>
${contents}
  </body>
</html>
`;
exports.default = page;
//# sourceMappingURL=page.js.map